==> haskell-bsb-http-chunked-0.0.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.3
id: bsb-http-chunked-0.0.0.3-7zJ3JordhTaA5FCKIEqhgh
key: bsb-http-chunked-0.0.0.3-7zJ3JordhTaA5FCKIEqhgh
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
           (c) 2018 Simon Jakobi
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: 0d25d6606814ce65107d8b4b4400f347
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
import-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bsb-http-chunked-0.0.0.3
hs-libraries: HSbsb-http-chunked-0.0.0.3-7zJ3JordhTaA5FCKIEqhgh
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.3
id: bsb-http-chunked-0.0.0.3-IefrTszFGe92c9xtbOyIpt
key: bsb-http-chunked-0.0.0.3-IefrTszFGe92c9xtbOyIpt
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
           (c) 2018 Simon Jakobi
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: b56da97fecd2f9b735473420068c1fa8
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
import-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bsb-http-chunked-0.0.0.3
hs-libraries: HSbsb-http-chunked-0.0.0.3-IefrTszFGe92c9xtbOyIpt
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
